import { LocalUser, useLocalMicrophoneTrack, useLocalCameraTrack, usePublish, useIsConnected } from 'agora-rtc-react';
import { useState, useEffect } from 'react';
import { UserOutlined } from '@ant-design/icons';
import { useLocalStorage } from '../../../../hooks/useLocalStorage';
import { AUTH_USER } from '../../../../constants/common';

type LocalUserPanelProps = {
    calling: boolean;
    micOn: boolean;
    cameraOn: boolean;
}

export const LocalUserPanel = ({
    calling,
    micOn,
    cameraOn
}: LocalUserPanelProps) => {
    const isConnected = useIsConnected();
    const [userData] = useLocalStorage(AUTH_USER, '');
    const { faceImageUrl: userImage = '' } = userData ? JSON.parse(userData) : {};

    const [playVideo, setPlayVideo] = useState(false);
    const [playAudio, setPlayAudio] = useState(false);

    const { localMicrophoneTrack } = useLocalMicrophoneTrack(micOn);
    const { localCameraTrack } = useLocalCameraTrack(cameraOn);
    usePublish([localMicrophoneTrack, localCameraTrack]);

    useEffect(() => {
        if (calling) {
            setPlayVideo(cameraOn)
        }
    }, [cameraOn]);

    useEffect(() => {
        if (calling) {
            setPlayAudio(micOn)
        }
    }, [micOn]);

    return calling && isConnected ? (
        <div className="b-agora__local_user">
            {!cameraOn && (
                <div className="b-agora__local_base">
                    <div className="b-agora__call_avatar" style={userImage ? { backgroundImage: `url(${userImage})` } : undefined}>
                        {!userImage && (<UserOutlined style={{ fontSize: 40, color: '#2C7873' }}/>)}
                    </div>
                </div>
            )}
            <LocalUser
                audioTrack={localMicrophoneTrack}
                cameraOn={cameraOn}
                micOn={micOn}
                playAudio={playAudio}
                playVideo={playVideo}
                style={{ width: '100%', height: '100%' }}
                videoTrack={localCameraTrack}
            />
        </div>
    ) : null;
};
